@@ -74,9 +74,27 @@ _UNKNOWN_OPEN_VALUE = 0xffff
 _USBXPRESS = usb.util.CTRL_OUT | usb.util.CTRL_TYPE_VENDOR | usb.util.CTRL_RECIPIENT_DEVICE
 
 
-class _CommonAsetekDriver(UsbDriver):
+class _Base690Lc(UsbDriver):
     """Common methods for Asetek 690LC devices."""
 
+    _LEGACY_690LC = False
+
+    @classmethod
+    def probe(cls, handle, legacy_690lc=False, **kwargs):
+        """Probe `handle` and yield corresponding driver instances."""
+        if legacy_690lc != cls._LEGACY_690LC:
+            return
+        yield from super().probe(handle, **kwargs)
+
+    @classmethod
+    def find_supported_devices(cls, **kwargs):
+        """Find devices specifically compatible with this driver.
+
+        Automatically sets the appropriate value for `legacy_690lc`.
+        """
+
+        return super().find_supported_devices(legacy_690lc=cls._LEGACY_690LC, **kwargs)
+
     def _configure_flow_control(self, clear_to_send):
         """Set the software clear-to-send flow control policy for device."""
         _LOGGER.debug('set clear to send = %s', clear_to_send)
@@ -169,44 +187,7 @@ class _CommonAsetekDriver(UsbDriver):
         super().disconnect(**kwargs)
 
 
-class Modern690Lc(_CommonAsetekDriver):
-    """Modern fifth generation Asetek 690LC cooler."""
-
-    SUPPORTED_DEVICES = [
-        (0x2433, 0xb200, None, 'Asetek 690LC (assuming EVGA CLC)', {}),
-    ]
-
-    @classmethod
-    def probe(cls, handle, legacy_690lc=False, **kwargs):
-        if legacy_690lc:
-            return
-        yield from super().probe(handle, **kwargs)
-
-    def downgrade_to_legacy(self):
-        """Take the device handle and return a new Legacy690Lc instance for it.
-
-        This method returns a new instance that takes the device handle from
-        `self`.  Because of this, the caller should immediately discard `self`,
-        as it is no longer valid to call any of its methods or access any of
-        its properties.
-
-        While it is sometimes possible to downgrade a device that has seen
-        modern traffic since it booted, this will generally not work.
-        Additionally, no attempt to disconnect from the device is made while
-        downgrading the instance.
-
-        Thus, callers are strongly advised to only call this function before
-        connecting to the device from this instance and, in fact, before
-        calling any other methods at all on the device, from any instance.
-
-        Finally, this method is not yet considered stable and its signature
-        and/or behavior may change.  Callers should follow the development of
-        liquidctl and the stabilization of this API.
-        """
-        legacy = Legacy690Lc(self.device, self._description)
-        self.device = None
-        self._description = None
-        return legacy
+class _ModernBase690Lc(_Base690Lc):
 
     def get_status(self, **kwargs):
         """Get a status report.
@@ -297,18 +278,48 @@ class Modern690Lc(_CommonAsetekDriver):
         self._end_transaction_and_read()
 
 
-class Legacy690Lc(_CommonAsetekDriver):
+class Modern690Lc(_ModernBase690Lc):
+    """Modern fifth generation Asetek 690LC cooler."""
+
+    SUPPORTED_DEVICES = [
+        (0x2433, 0xb200, None, 'Asetek 690LC (assuming EVGA CLC)', {}),
+    ]
+
+    def downgrade_to_legacy(self):
+        """Take the device handle and return a new Legacy690Lc instance for it.
+
+        This method returns a new instance that takes the device handle from
+        `self`.  Because of this, the caller should immediately discard `self`,
+        as it is no longer valid to call any of its methods or access any of
+        its properties.
+
+        While it is sometimes possible to downgrade a device that has seen
+        modern traffic since it booted, this will generally not work.
+        Additionally, no attempt to disconnect from the device is made while
+        downgrading the instance.
+
+        Thus, callers are strongly advised to only call this function before
+        connecting to the device from this instance and, in fact, before
+        calling any other methods at all on the device, from any instance.
+
+        Finally, this method is not yet considered stable and its signature
+        and/or behavior may change.  Callers should follow the development of
+        liquidctl and the stabilization of this API.
+        """
+        legacy = Legacy690Lc(self.device, self._description)
+        self.device = None
+        self._description = None
+        return legacy
+
+
+class Legacy690Lc(_Base690Lc):
     """Legacy fifth generation Asetek 690LC cooler."""
 
     SUPPORTED_DEVICES = [
-        (0x2433, 0xb200, None, 'Asetek 690LC (assuming NZXT Kraken X) (experimental)', {}),
+        (0x2433, 0xb200, None, 'Asetek 690LC (assuming NZXT Kraken X)', {}),
     ]
 
-    @classmethod
-    def probe(cls, handle, legacy_690lc=False, **kwargs):
-        if not legacy_690lc:
-            return
-        yield from super().probe(handle, **kwargs)
+    _LEGACY_690LC = True
 
     def __init__(self, device, description, **kwargs):
         super().__init__(device, description, **kwargs)
@@ -400,7 +411,7 @@ class Legacy690Lc(_CommonAsetekDriver):
         raise NotSupportedByDevice
 
 
-class Hydro690Lc(Modern690Lc):
+class Hydro690Lc(_ModernBase690Lc):
     """Corsair-branded fifth generation Asetek 690LC cooler."""
 
     SUPPORTED_DEVICES = [
@@ -412,12 +423,6 @@ class Hydro690Lc(Modern690Lc):
         (0x1b1c, 0x0c0a, None, 'Corsair Hydro H115i', {}),
     ]
 
-    @classmethod
-    def probe(cls, handle, legacy_690lc=False, **kwargs):
-        # the modern driver overrides probe and rigs it to switch on
-        # --legacy-690lc, so we override it again
-        return super().probe(handle, legacy_690lc=False, **kwargs)
-
     def set_color(self, channel, mode, colors, **kwargs):
         """Set the color mode for a specific channel."""
         if mode == 'rainbow':
