@@ -32,9 +32,9 @@ class NzxtEPsu(UsbHidDriver):
     """NZXT E-series power supply unit."""
 
     SUPPORTED_DEVICES = [
-        (0x7793, 0x5911, None, 'NZXT E500 (experimental)', {}),
-        (0x7793, 0x5912, None, 'NZXT E650 (experimental)', {}),
-        (0x7793, 0x2500, None, 'NZXT E850 (experimental)', {}),
+        (0x7793, 0x5911, None, 'NZXT E500', {}),
+        (0x7793, 0x5912, None, 'NZXT E650', {}),
+        (0x7793, 0x2500, None, 'NZXT E850', {}),
     ]
 
     def initialize(self, **kwargs):
